@@ -10,11 +10,14 @@ from sympy.core.sympify import SympifyError
 from tqdm import tqdm
 from torchvision.models import efficientnet_b0, EfficientNet_B0_Weights
 import timm
+import os
 
 BATCH_SIZE = 16
 CORES = 16
 TOTAL_EPOCHS = 25
-JSON_PATH = './datasets/val.json'
+import os
+
+JSON_PATH = os.path.join(os.path.dirname(__file__), 'datasets', 'val.json')
 PT_SAVE = 'graphite_test_val.pt'
 
 def collate_fn(batch):
